using System.Reflection;
using UnityEngine;
using UnityEngine.EventSystems;
using UnityEngine.UI;

public class DropMe : MonoBehaviour, IDropHandler, IPointerEnterHandler, IPointerExitHandler
{
	public Image containerImage;
	public Image receivingImage;
	public string dropName;
	public Color highlightColor = Color.yellow;

	private Color normalColor;

	
	public void OnEnable ()
	{
		if (containerImage != null)
			normalColor = containerImage.color;
	}
	
	public void OnDrop(PointerEventData data)
	{
		containerImage.color = normalColor;
		
		if (receivingImage == null)
			return;
		
		Sprite dropSprite = GetDropSprite (data);

		var dragObj = data.pointerDrag; //create a reference to the draggable object.

		Debug.Log(this.dropName);
		Debug.Log(dragObj.GetComponent<DragMe>().correctTarget);

		Text feedbackRef = GameObject.FindWithTag("feedback").GetComponent<Text>();


		//GUI.color = thisColor;

		if (dropSprite != null) 
		{
			//if they hit the correct target, then snap that image onto the drop target.
			if(this.dropName == dragObj.GetComponent<DragMe>().correctTarget) {
				receivingImage.overrideSprite = dropSprite;
				//show correct response feedback.
				Color thisColor = GUI.color;
				thisColor.a = 0.5f;
				dragObj.GetComponent<Image>().color = thisColor;
				feedbackRef.text = dragObj.GetComponent<DragMe>().correctResponse;
			} else {
				//show incorrect response feedback.
				feedbackRef.text = dragObj.GetComponent<DragMe>().incorrectResponse;
			}
		}
	}

	public void OnPointerEnter(PointerEventData data)
	{
		if (containerImage == null)
			return;
		
		Sprite dropSprite = GetDropSprite (data);
		if (dropSprite != null)
			containerImage.color = highlightColor;
	}

	public void OnPointerExit(PointerEventData data)
	{
		if (containerImage == null)
			return;
		
		containerImage.color = normalColor;
	}
	
	private Sprite GetDropSprite(PointerEventData data)
	{
		var originalObj = data.pointerDrag;
		if (originalObj == null)
			return null;

		var srcImage = originalObj.GetComponent<Image>();
		if (srcImage == null)
			return null;

		return srcImage.sprite;
	}
}
